<?php

declare(strict_types=1);

namespace Dedi\SyliusMailAdminPlugin\Repository;

use Doctrine\ORM\NonUniqueResultException;
use Doctrine\ORM\Query;
use Doctrine\ORM\QueryBuilder;
use Sylius\Bundle\ResourceBundle\Doctrine\ORM\EntityRepository;

class MailRepository extends EntityRepository implements MailRepositoryInterface
{
    protected function createTranslationBasedQueryBuilder(?string $locale = null): QueryBuilder
    {
        $queryBuilder = $this->createQueryBuilder('o')
            ->addSelect('translation')
            ->innerJoin('o.translations', 'translation', 'WITH', 'translation.locale = :locale');

        if (null !== $locale) {
            $queryBuilder
                ->andWhere('translation.locale = :locale')
                ->setParameter('locale', $locale);
        }

        return $queryBuilder;
    }

    public function findByCode(string $code, ?int $excludedMailId = null): array
    {
        $builder = $this->createQueryBuilder('o');
        $builder
            ->andWhere('o.code = :code')
            ->setParameter('code', $code);

        if (null !== $excludedMailId) {
            $builder
                ->andWhere('o.id != :excludedId')
                ->setParameter('excludedId', $excludedMailId);
        }

        return $builder->getQuery()->getResult();
    }

    /**
     * @param string $code
     * @param string $locale
     *
     * @return int|mixed|string|null
     *
     * @throws NonUniqueResultException
     */
    public function findEnabledTranslatableByCode(string $code, string $locale)
    {
        $builder = $this->createTranslationBasedQueryBuilder($locale);
        $builder
            ->andWhere('o.enabled = :enabled')
            ->andWhere('o.code = :code')
            ->setParameter('code', $code)
            ->setParameter('enabled', true)
        ;

        return $builder->getQuery()->getOneOrNullResult(Query::HYDRATE_OBJECT);
    }
}
